@@ -15,6 +15,4 @@ VALID_METHODS = ("GET", "POST", "PUT", "DELETE")
 VALID_AUTH_PROVIDERS = ("URL", "USER_INFO", "SASL_INHERIT")
 
 HEADERS = "application/vnd.schemaregistry.v1+json"
-ACCEPT_HEADERS = (
-    "application/vnd.schema_registry.v1+json, application/vnd.schema_registry+json, application/json"
-)  # noqa
+ACCEPT_HEADERS = "application/vnd.schema_registry.v1+json, application/vnd.schema_registry+json, application/json"
